package db;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;

import data.Post;

public class HibernatePostDao implements IPostDao {

	@Override
	public void createPost(Post post) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		session.save(post);
		session.getTransaction().commit();
	}

	@Override
	public Post findById(int id) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		Post post = (Post)session.get(Post.class, id);
		session.getTransaction().commit();
		return post;		
	}
	
	@SuppressWarnings("unchecked")
	@Override
	public List<Post> findByHeader(String header) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		Criteria criteria = session.createCriteria(Post.class).add(Restrictions.like("header", "%"+header+"%"));
		List<Post> result = criteria.list();
		session.getTransaction().commit();
		return result;
	}
	
	@SuppressWarnings("unchecked")
	@Override
	public List<Post> findByCategory(String category) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		Criteria criteria = session.createCriteria(Post.class).add(Restrictions.like("category", "%"+category+"%"));
		List<Post> result = criteria.list();
		session.getTransaction().commit();
		return result;
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<Post> findByDate(String date) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		Criteria criteria = session.createCriteria(Post.class).add(Restrictions.eq("date", date));
		List<Post> result = criteria.list();
		session.getTransaction().commit();
		return result;
	}

	@SuppressWarnings("unchecked")
	@Override
	public List<Post> findByPoster(String poster) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		Criteria criteria = session.createCriteria(Post.class).add(Restrictions.eq("poster", poster));
		List<Post> result = criteria.list();
		session.getTransaction().commit();
		return result;
	}
	
	@Override
	public void updatePost(Post post) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		session.update(post);			
		session.getTransaction().commit();
	}

	@Override
	public void deletePost(Post post) {
		Session session = DatabaseHandler.getSession();
		session.beginTransaction();
		session.delete(post);
		session.getTransaction().commit();
	}

}
