package tests;

import static org.junit.Assert.*;

import java.text.DateFormat;
import java.util.Date;

import org.junit.Test;

import data.Post;

import db.MockPostDao;

import services.PostManager;

public class PostManagerTest {
	
	static PostManager man = new PostManager(new MockPostDao());
	Post post;
	
	@Test
	public void createTest() {
		post = man.createPost("header", "body", "poster", "category");
		assertFalse(post == null);
		man.deletePost(post);
	}
		
	@Test
	public void findByIdTest() {
		post = man.createPost("header", "body", "poster", "category");
		assertEquals(man.findById(post.getID()).getID(), post.getID());
		man.deletePost(post);
	}	
	
	@Test
	public void findByHeaderTest() {
		post = man.createPost("header", "body", "poster", "category");
		assertEquals(man.findByHeader("header").get(0).getHeader(), "header");
		man.deletePost(post);
	}
	
	@Test
	public void findByPosterTest() {
		post = man.createPost("header", "body", "poster", "category");
		assertEquals(man.findByPoster("poster").get(0).getPoster(), "poster");
		man.deletePost(post);
	}
	
	@Test
	public void findByDateTest() {
		post = man.createPost("header", "body", "poster", "category");
		assertEquals(man.findByDate(DateFormat.getDateInstance(DateFormat.SHORT).format(new Date())).get(0).getDate(), post.getDate());
		man.deletePost(post);
	}
	
	@Test
	public void changePostTest() {
		post = man.createPost("header", "body", "poster", "category");
		man.changePost(post, "newHeader", "newBody");
		assertEquals(man.findById(post.getID()).getHeader(), "newHeader");
		man.deletePost(post);
	}
	
	@Test
	public void deletePostTest() {
		post = man.createPost("header", "body", "poster", "category");
		man.deletePost(post);
		assertEquals(man.findById(post.getID()), null);
	}
	
}
