package tests;

import static org.junit.Assert.*;

import org.junit.Test;

import db.MockUserDao;

import services.UserManager;

public class UserManagerTest {

	static UserManager man = new UserManager(new MockUserDao());
	
	@Test
	public void createTest() {
		assertFalse(man.createUser("name", "password", "firstName", "lastName") == null);
		man.deleteUser("name");
	}
			
	@Test
	public void existsTest() {
		man.createUser("name", "password", "firstName", "lastName");
		assertTrue(man.exists("name"));
		man.deleteUser("name");
	}
	
	@Test
	public void deleteTest() {
		man.createUser("name", "password", "firstName", "lastName");
		man.deleteUser("name");
		assertFalse(man.exists("name"));
	}
	
	@Test
	public void findByUserNameTest() {
		man.createUser("name", "password", "firstName", "lastName");
		assertEquals(man.findByUserName("name").getUserName(), "name");
		man.deleteUser("name");
	}
			
	@Test
	public void changeNameTest() {
		man.createUser("name", "password", "firstName", "lastName");
		man.changeName(man.findByUserName("name"), "newFirstName", "newLastName");
		assertEquals(man.findByUserName("name").getFirstName(),"newFirstName");
		assertEquals(man.findByUserName("name").getLastName(),"newLastName");
		man.deleteUser("name");
	}
	
	@Test
	public void changePasswordTest() {
		man.createUser("name", "password", "firstName", "lastName");
		man.changePassword(man.findByUserName("name"), "password", "newPassword");
		assertEquals(man.findByUserName("name").getPassword(), "newPassword");
		man.deleteUser("name");
	}
	
	@Test
	public void failChangePasswordTest() {
		man.createUser("name", "password", "firstName", "lastName");
		man.changePassword(man.findByUserName("name"), "wrongPassword", "newPassword");
		assertEquals(man.findByUserName("name").getPassword(), "password");
		man.deleteUser("name");
	}
	
	@Test
	public void loginTest() {
		man.createUser("name", "password", "firstName", "lastName");
		assertTrue(man.login("name", "password") != null);
		man.deleteUser("name");
	}
	
	@Test
	public void failLoginTest() {
		man.createUser("name", "password", "firstName", "lastName");
		assertTrue(man.login("name", "wrongPassword") == null);
		man.deleteUser("name");
	}
}
