package web;

import org.apache.wicket.Session;
import org.apache.wicket.markup.html.WebPage;
import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.request.Request;
import org.apache.wicket.request.Response;
import org.apache.wicket.settings.IExceptionSettings;

import services.PostManager;
import services.UserManager;

import db.DatabaseHandler;
import db.HibernatePostDao;
import db.HibernateUserDao;

import web.pages.HomePage;

public class WicketApplication extends WebApplication {

	private UserManager userManager = new UserManager(new HibernateUserDao());
	private PostManager postManager = new PostManager(new HibernatePostDao());

	@Override
	public Class<? extends WebPage> getHomePage() {
		return HomePage.class;
	}

	@Override
	public Session newSession(Request request, Response response) {	
		return new MySession(request);
	}

	@Override
	public void init() {
		super.init();
		getExceptionSettings().setUnexpectedExceptionDisplay(IExceptionSettings.SHOW_INTERNAL_ERROR_PAGE); 
		DatabaseHandler.connect();
	}

	public UserManager getUserManager() {
		return userManager;
	}

	public PostManager getPostManager() {
		return postManager;
	}

}
