package web.pages;

import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.request.mapper.parameter.PageParameters;

import web.WicketApplication;

@SuppressWarnings("serial")
public class HomePage extends MyWebPage {

	public HomePage() {
		add(new BookmarkablePageLink<Void>("nameLink", ProfilePage.class).add(nameLabel));
		add(logInLink);
		add(logOutLink);
		add(registerLink);
		add(categoryList);
		add(addPostLink);
		add(new FeedbackPanel("feedback"));
	}

	private Label nameLabel = new Label("name", getMySession().getUserName()) {
		@Override
		public boolean isVisible() {
			return getMySession().isActive();
		}
	};

	private Link<Void> logInLink = new BookmarkablePageLink<Void>("logInLink", LoginPage.class) {
		@Override
		public boolean isVisible() {
			return !getMySession().isActive();
		}
	};

	private Link<Void> logOutLink = new Link<Void>("logOutLink") {
		@Override
		public void onClick() {
			getMySession().invalidate();
			setResponsePage(LoginPage.class); 
		}

		@Override
		public boolean isVisible() {
			return getMySession().isActive();
		}
	};

	private Link<Void> registerLink = new BookmarkablePageLink<Void>("registerLink", RegisterPage.class) {
		@Override
		public boolean isVisible() {
			return !getMySession().isActive();
		}
	};

	private Link<Void> addPostLink = new BookmarkablePageLink<Void>("newPostLink", AddPostPage.class) {
		@Override
		public boolean isVisible() {
			return getMySession().isActive();
		}
	};

	private ListView<String> categoryList = new ListView<String>("categoryList", ((WicketApplication)getApplication()).getPostManager().getCategoryList()) {
		@Override 
		public void populateItem(ListItem<String> item) {
			PageParameters parameters = new PageParameters();
			parameters.add("categoryName", item.getModelObject());
			item.add(new BookmarkablePageLink<Void>("category", CategoryPage.class, parameters).add(new Label("categoryName", item.getModel()))); 
		} 
	};


}
