package web.pages;

import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.RequiredTextField;
import org.apache.wicket.markup.html.form.SubmitLink;
import org.apache.wicket.markup.html.form.TextArea;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.PropertyModel;
import org.apache.wicket.request.mapper.parameter.PageParameters;

import data.Post;

import web.WicketApplication;

@SuppressWarnings("serial")
public class PostPage extends MyWebPage {

	private Post post;
	boolean editMode = false;

	public PostPage(PageParameters parameters) {
		int postID = parameters.get("postID").toInt(); 
		post = ((WicketApplication)getApplication()).getPostManager().findById(postID);
		add(new Label("postName", post.getHeader()));
		add(new Label("header", post.getHeader()));
		add(new Label("body", post.getBody()));
		add(new Label("poster", post.getPoster()));
		add(new Label("date", post.getDate()));
		add(editPostLink);
		add(deletePostLink);
		parameters.add("categoryName", post.getCategory());
		add(new BookmarkablePageLink<Void>("categoryLink", CategoryPage.class, parameters));
		add(new BookmarkablePageLink<Void>("homeLink", HomePage.class));
		add(new EditForm("editForm"));
		add(new FeedbackPanel("feedback"));
	}

	private Link<Void> editPostLink = new Link<Void>("editPostLink") {
		@Override
		public void onClick() {
			editMode = !editMode;
		} 

		@Override
		public boolean isVisible() {
			if (post.getPoster().equals(getMySession().getUserName()))
			{
				return true;
			}
			else
			{
				return false;
			}
		}
	};

	private Link<Void> deletePostLink = new Link<Void>("deletePostLink") {
		@Override
		public void onClick() {
			((WicketApplication)getApplication()).getPostManager().deletePost(post);
			setResponsePage(HomePage.class);
		} 

		@Override
		public boolean isVisible() {
			if (post.getPoster().equals(getMySession().getUserName()))
			{
				return true;
			}
			else
			{
				return false;
			}
		}
	};


	private class EditForm extends Form<Void> {
		private String header = post.getHeader();
		private String body = post.getBody();

		public EditForm(String id) {
			super(id);
			add(new RequiredTextField<String>("Header", new PropertyModel<String>(this, "header")));
			add(new TextArea<String>("Body", new PropertyModel<String>(this, "body")).setRequired(true));
			add(new SubmitLink("editPost"));
		}

		@Override
		public void onSubmit() {
			((WicketApplication)getApplication()).getPostManager().changePost(post, header, body);
			PageParameters parameters = new PageParameters();
			parameters.add("postID", post.getID());
			setResponsePage(PostPage.class, parameters);
		}

		@Override
		public boolean isVisible() {
			return editMode;
		}

	}
}
