package web.pages;

import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.PasswordTextField;
import org.apache.wicket.markup.html.form.RequiredTextField;
import org.apache.wicket.markup.html.form.SubmitLink;
import org.apache.wicket.markup.html.link.BookmarkablePageLink;
import org.apache.wicket.markup.html.link.Link;
import org.apache.wicket.markup.html.panel.FeedbackPanel;
import org.apache.wicket.model.PropertyModel;

import web.WicketApplication;

import data.User;

@SuppressWarnings("serial")
public class ProfilePage extends MyWebPage {

	User user = getMySession().getUser();
	boolean profileEditMode = false;
	boolean passwordEditMode = false;

	public ProfilePage() {
		add(new Label("userNameTitle", user.getUserName()));
		add(new Label("userName", user.getUserName()));
		add(new Label("firstName", user.getFirstName()));
		add(new Label("lastName", user.getLastName()));
		add(changeProfileLink);
		add(changePasswordLink);
		add(new ProfileForm("profileForm"));
		add(new PasswordForm("passwordForm"));
		add(new BookmarkablePageLink<Void>("homeLink", HomePage.class)); 
		add(new FeedbackPanel("feedback"));
	}

	private Link<Void> changeProfileLink = new Link<Void>("changeProfileLink") {
		@Override
		public void onClick() {
			passwordEditMode = false;
			profileEditMode = !profileEditMode;
		}    
	};	

	private Link<Void> changePasswordLink = new Link<Void>("changePasswordLink") {
		@Override
		public void onClick() {
			profileEditMode = false;
			passwordEditMode = !passwordEditMode;
		} 
	};

	public class ProfileForm extends Form<Void> {
		private String newFirstName = user.getFirstName();
		private String newLastName = user.getLastName();

		public ProfileForm(String id) {
			super(id);
			add(new RequiredTextField<String>("First Name", new PropertyModel<String>(this, "newFirstName")));
			add(new RequiredTextField<String>("Last Name", new PropertyModel<String>(this, "newLastName")));
			add(new SubmitLink("changeProfile"));
		}

		@Override
		public void onSubmit() {
			((WicketApplication)getApplication()).getUserManager().changeName(user, newFirstName, newLastName);
			setResponsePage(ProfilePage.class);
		}

		@Override
		public boolean isVisible() {
			return profileEditMode;
		}

	}

	public class PasswordForm extends Form<Void> {
		private String password;
		private String newPassword;
		private String confirmPassword;

		public PasswordForm(String id) {
			super(id);
			add(new PasswordTextField("Password", new PropertyModel<String>(this, "password")));
			add(new PasswordTextField("New Password", new PropertyModel<String>(this, "newPassword")));
			add(new PasswordTextField("Confirm Password", new PropertyModel<String>(this, "confirmPassword")));
			add(new SubmitLink("changePassword"));
		}

		@Override
		public void onSubmit() {
			if (newPassword.equals(confirmPassword))
			{
				if(((WicketApplication)getApplication()).getUserManager().changePassword(user, password, newPassword))
				{
					setResponsePage(ProfilePage.class);
				}
				else
				{
					info("Wrong password.");
				}
			}
			else
			{
				info("Passwords don't match.");
			}
		}

		@Override
		public boolean isVisible() {
			return passwordEditMode;
		}
	}

}
